/*
 * Muokkaa tätä tiedostoa ja kopioi nimellä userContent.css 
 * profiilikansiosi chrome-kansioon
 */

/*
 * Tätä tiedostoa muokkaamalla on mahdollista muuttaa kaikkien ohjelmalla
 * avattujen WWW-sivujen ulkonäköä. Säännöt, joissa on !important-lisäys,
 * korvaavat sivun tekijän antamat samannimiset säännöt. Jos lisäystä ei 
 * löydy, sivulle asetetut tyylit voivat korvata tässä tiedostossa annetut.
 */

/*
 * esimerkki: estetään blink-elementtiä vilkkumasta
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * esimerkki: asetetaan kaikille taulukoille kahden kuvapisteen reunat
 *
 * table { border: 2px solid; }
 */

/*
 * esimerkki: estetään marquee-elementtin sisällön vieriminen
 *
 * marquee { -moz-binding: none; }
 *
 */
 
/* 
 * Lisää esimerkkejä säännöistä (englanniksi) osoitteesta 
 * http://www.mozilla.org/unix/customizing.html
 */

/* 
 * Firefox 1.5:ssä ja uudemmissa on myös mahdollista asettaa 
 * sivustokohtaisia CSS-sääntöjä. Lähimpänä virallista lähdettä on 
 * kirjoitushetkellä viesti:
 * http://lists.w3.org/Archives/Public/www-style/2004Aug/0135.html
 *
 * Esimerkkinä toimivasta säännöstä seuraava:
 */

/* Poista sivuston mondediplo.comin hakemiston 2005 sivujen 
 * muodostavasta taulukosta ensimmäinen otsikkorivi.
 * 
 * @-moz-document url-prefix(http://mondediplo.com/2005/),
 *                domain(mondediple.com)
 * {
 *  tr:first-child {display:none;}
 * }
 *
 */
